@@ -4,14 +4,12 @@
 /* ************************************************************************** */
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
-/* * file      : libmng_jpeg.c             copyright (c) 2000-2002 G.Juyn   * */
-/* * version   : 1.0.5                                                      * */
+/* * file      : libmng_jpeg.c             copyright (c) 2000-2004 G.Juyn   * */
+/* * version   : 1.0.8                                                      * */
 /* *                                                                        * */
 /* * purpose   : JPEG library interface (implementation)                    * */
 /* *                                                                        * */
 /* * author    : G.Juyn                                                     * */
-/* * web       : http://www.3-t.com                                         * */
-/* * email     : mailto:info@3-t.com                                        * */
 /* *                                                                        * */
 /* * comment   : implementation of the JPEG library interface               * */
 /* *                                                                        * */
@@ -46,6 +44,12 @@
 /* *             1.0.5 - 24/02/2003 - G.Juyn                                * */
 /* *             - B683152 - libjpeg suspension not always honored correctly* */
 /* *                                                                        * */
+/* *             1.0.6 - 03/04/2003 - G.Juyn                                * */
+/* *             - fixed some compiler-warnings                             * */
+/* *                                                                        * */
+/* *             1.0.8 - 08/01/2004 - G.Juyn                                * */
+/* *             - added support for 3+byte pixelsize for JPEG's            * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #include "libmng.h"
@@ -551,7 +555,7 @@ mng_retcode mngjpeg_decompressdata (mng_datap  pData,
           pData->fDisplayrow = MNG_NULL;
                                        /* allocate a row of JPEG-samples */
         if (pData->pJPEGdinfo->jpeg_color_space == JCS_YCbCr)
-          pData->iJPEGrowlen = pData->pJPEGdinfo->image_width * 3;
+          pData->iJPEGrowlen = pData->pJPEGdinfo->image_width * RGB_PIXELSIZE;
         else
           pData->iJPEGrowlen = pData->pJPEGdinfo->image_width;
 
@@ -588,7 +592,7 @@ mng_retcode mngjpeg_decompressdata (mng_datap  pData,
          (pData->pJPEGdinfo->output_scanline < pData->pJPEGdinfo->output_height) ||
          ((pData->bJPEGprogressive) && (pData->bJPEGscanending))))
     {
-      mng_int32 iLines;
+      mng_int32 iLines = 0;
 
       /* for (each output pass) */
       do
@@ -896,7 +900,7 @@ mng_retcode mngjpeg_decompressdata2 (mng_datap  pData,
           MNG_ERROR (pData, MNG_JPEGPARMSERR)
                                        /* allocate a row of JPEG-samples */
         if (pData->pJPEGdinfo2->jpeg_color_space == JCS_YCbCr)
-          pData->iJPEGrowlen2 = pData->pJPEGdinfo2->image_width * 3;
+          pData->iJPEGrowlen2 = pData->pJPEGdinfo2->image_width * RGB_PIXELSIZE;
         else
           pData->iJPEGrowlen2 = pData->pJPEGdinfo2->image_width;
 
