@@ -4,14 +4,12 @@
 /* ************************************************************************** */
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
-/* * file      : libmng_object_prc.h       copyright (c) 2000-2002 G.Juyn   * */
-/* * version   : 1.0.5                                                      * */
+/* * file      : libmng_object_prc.h       copyright (c) 2000-2004 G.Juyn   * */
+/* * version   : 1.0.7                                                      * */
 /* *                                                                        * */
 /* * purpose   : Object processing routines (definition)                    * */
 /* *                                                                        * */
 /* * author    : G.Juyn                                                     * */
-/* * web       : http://www.3-t.com                                         * */
-/* * email     : mailto:info@3-t.com                                        * */
 /* *                                                                        * */
 /* * comment   : Definition of the internal object processing routines      * */
 /* *                                                                        * */
@@ -52,6 +50,15 @@
 /* *             1.0.5 - 10/07/2002 - G.Juyn                                * */
 /* *             - fixed DISC support                                       * */
 /* *                                                                        * */
+/* *             1.0.6 - 07/07/2003 - G.R-P                                 * */
+/* *             - added conditionals around Delta-PNG code                 * */
+/* *             - added SKIPCHUNK feature                                  * */
+/* *             1.0.6 - 07/29/2003 - G.R-P                                 * */
+/* *             - added conditionals around PAST chunk support             * */
+/* *                                                                        * */
+/* *             1.0.7 - 03/24/2004 - G.R-P                                 * */
+/* *             - added more SKIPCHUNK conditionals                        * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #if defined(__BORLANDC__) && defined(MNG_STRICT_ANSI)
@@ -288,11 +295,15 @@ mng_retcode mng_create_ani_term   (mng_datap      pData,
                                    mng_uint32     iDelay,
                                    mng_uint32     iItermax);
 
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_retcode mng_create_ani_save   (mng_datap      pData);
+#endif
+#ifndef MNG_SKIPCHUNK_SEEK
 mng_retcode mng_create_ani_seek   (mng_datap      pData,
                                    mng_uint32     iSegmentnamesize,
                                    mng_pchar      zSegmentname);
-
+#endif
+#ifndef MNG_NO_DELTA_PNG
 mng_retcode mng_create_ani_dhdr   (mng_datap      pData,
                                    mng_uint16     iObjectid,
                                    mng_uint8      iImagetype,
@@ -316,7 +327,9 @@ mng_retcode mng_create_ani_pplt   (mng_datap      pData,
                                    mng_palette8ep paIndexentries,
                                    mng_uint8p     paAlphaentries,
                                    mng_uint8p     paUsedentries);
+#endif
 
+#ifndef MNG_SKIPCHUNK_MAGN
 mng_retcode mng_create_ani_magn   (mng_datap      pData,
                                    mng_uint16     iFirstid,
                                    mng_uint16     iLastid,
@@ -328,7 +341,9 @@ mng_retcode mng_create_ani_magn   (mng_datap      pData,
                                    mng_uint16     iMT,
                                    mng_uint16     iMB,
                                    mng_uint8      iMethodY);
+#endif
 
+#ifndef MNG_SKIPCHUNK_PAST
 mng_retcode mng_create_ani_past   (mng_datap      pData,
                                    mng_uint16     iTargetid,
                                    mng_uint8      iTargettype,
@@ -336,10 +351,13 @@ mng_retcode mng_create_ani_past   (mng_datap      pData,
                                    mng_int32      iTargety,
                                    mng_uint32     iCount,
                                    mng_ptr        pSources);
+#endif
 
+#ifndef MNG_SKIPCHUNK_DISC
 mng_retcode mng_create_ani_disc   (mng_datap      pData,
                                    mng_uint32     iCount,
                                    mng_uint16p    pIds);
+#endif
 
 /* ************************************************************************** */
 
@@ -352,18 +370,28 @@ mng_retcode mng_free_ani_trns     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_gama     (mng_datap    pData,
                                    mng_objectp  pObject);
+#ifndef MNG_SKIPCHUNK_cHRM
 mng_retcode mng_free_ani_chrm     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_sRGB
 mng_retcode mng_free_ani_srgb     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_iCCP
 mng_retcode mng_free_ani_iccp     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_bKGD
 mng_retcode mng_free_ani_bkgd     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_LOOP
 mng_retcode mng_free_ani_loop     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_endl     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
 mng_retcode mng_free_ani_defi     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_basi     (mng_datap    pData,
@@ -382,10 +410,15 @@ mng_retcode mng_free_ani_show     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_term     (mng_datap    pData,
                                    mng_objectp  pObject);
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_retcode mng_free_ani_save     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_retcode mng_free_ani_seek     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_NO_DELTA_PNG
 mng_retcode mng_free_ani_dhdr     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_prom     (mng_datap    pData,
@@ -396,10 +429,15 @@ mng_retcode mng_free_ani_ijng     (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_free_ani_pplt     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_MAGN
 mng_retcode mng_free_ani_magn     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_PAST
 mng_retcode mng_free_ani_past     (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
 mng_retcode mng_free_ani_disc     (mng_datap    pData,
                                    mng_objectp  pObject);
 
@@ -414,18 +452,28 @@ mng_retcode mng_process_ani_trns  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_gama  (mng_datap    pData,
                                    mng_objectp  pObject);
+#ifndef MNG_SKIPCHUNK_cHRM
 mng_retcode mng_process_ani_chrm  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_sRGB
 mng_retcode mng_process_ani_srgb  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_iCCP
 mng_retcode mng_process_ani_iccp  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_bKGD
 mng_retcode mng_process_ani_bkgd  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_LOOP
 mng_retcode mng_process_ani_loop  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_endl  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
 mng_retcode mng_process_ani_defi  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_basi  (mng_datap    pData,
@@ -444,10 +492,15 @@ mng_retcode mng_process_ani_show  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_term  (mng_datap    pData,
                                    mng_objectp  pObject);
+#ifndef MNG_SKIPCHUNK_SAVE
 mng_retcode mng_process_ani_save  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_SKIPCHUNK_SEEK
 mng_retcode mng_process_ani_seek  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
+#ifndef MNG_NO_DELTA_PNG
 mng_retcode mng_process_ani_dhdr  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_prom  (mng_datap    pData,
@@ -458,10 +511,13 @@ mng_retcode mng_process_ani_ijng  (mng_datap    pData,
                                    mng_objectp  pObject);
 mng_retcode mng_process_ani_pplt  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
 mng_retcode mng_process_ani_magn  (mng_datap    pData,
                                    mng_objectp  pObject);
+#ifndef MNG_SKIPCHUNK_PAST
 mng_retcode mng_process_ani_past  (mng_datap    pData,
                                    mng_objectp  pObject);
+#endif
 mng_retcode mng_process_ani_disc  (mng_datap    pData,
                                    mng_objectp  pObject);
 
