@@ -5,7 +5,7 @@
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
 /* * file      : libmng_prop_xs.c          copyright (c) 2000-2004 G.Juyn   * */
-/* * version   : 1.0.7                                                      * */
+/* * version   : 1.0.8                                                      * */
 /* *                                                                        * */
 /* * purpose   : property get/set interface (implementation)                * */
 /* *                                                                        * */
@@ -99,6 +99,9 @@
 /* *             1.0.7 - 03/07/2004 - G. Randers-Pehrson                    * */
 /* *             - put gamma, cms-related functions inside #ifdef           * */
 /* *                                                                        * */
+/* *             1.0.8 - 04/02/2004 - G.Juyn                                * */
+/* *             - added CRC existence & checking flags                     * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #include "libmng.h"
@@ -402,6 +405,26 @@ mng_retcode MNG_DECL mng_set_doprogressive (mng_handle hHandle,
 
 /* ************************************************************************** */
 
+mng_retcode MNG_DECL mng_set_crcmode (mng_handle hHandle,
+                                      mng_uint32 iCrcmode)
+{
+#ifdef MNG_SUPPORT_TRACE
+  MNG_TRACE (((mng_datap)hHandle), MNG_FN_SET_CRCMODE, MNG_LC_START)
+#endif
+
+  MNG_VALIDHANDLE (hHandle)
+
+  ((mng_datap)hHandle)->iCrcmode = iCrcmode;
+
+#ifdef MNG_SUPPORT_TRACE
+  MNG_TRACE (((mng_datap)hHandle), MNG_FN_SET_CRCMODE, MNG_LC_END)
+#endif
+
+  return MNG_NOERROR;
+}
+
+/* ************************************************************************** */
+
 #ifdef MNG_SUPPORT_DISPLAY
 mng_retcode MNG_DECL mng_set_srgb (mng_handle hHandle,
                                    mng_bool   bIssRGB)
@@ -1757,6 +1780,23 @@ mng_bool MNG_DECL mng_get_doprogressive (mng_handle hHandle)
 
 /* ************************************************************************** */
 
+mng_uint32 MNG_DECL mng_get_crcmode (mng_handle hHandle)
+{
+#ifdef MNG_SUPPORT_TRACE
+  MNG_TRACEB (((mng_datap)hHandle), MNG_FN_GET_CRCMODE, MNG_LC_START)
+#endif
+
+  MNG_VALIDHANDLEX (hHandle)
+
+#ifdef MNG_SUPPORT_TRACE
+  MNG_TRACEB (((mng_datap)hHandle), MNG_FN_GET_CRCMODE, MNG_LC_END)
+#endif
+
+  return ((mng_datap)hHandle)->iCrcmode;
+}
+
+/* ************************************************************************** */
+
 #ifdef MNG_SUPPORT_DISPLAY
 mng_bool MNG_DECL mng_get_srgb (mng_handle hHandle)
 {
