@@ -5,7 +5,7 @@
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
 /* * file      : libmng_trace.c            copyright (c) 2000-2004 G.Juyn   * */
-/* * version   : 1.0.7                                                      * */
+/* * version   : 1.0.8                                                      * */
 /* *                                                                        * */
 /* * purpose   : Trace functions (implementation)                           * */
 /* *                                                                        * */
@@ -138,6 +138,11 @@
 /* *             1.0.7 - 03/10/2004 - G.R-P                                 * */
 /* *             - added conditionals around openstream/closestream         * */
 /* *                                                                        * */
+/* *             1.0.8 - 04/02/2004 - G.Juyn                                * */
+/* *             - added CRC existence & checking flags                     * */
+/* *             1.0.8 - 04/11/2004 - G.Juyn                                * */
+/* *             - added data-push mechanisms for specialized decoders      * */
+/* *                                                                        * */
 /* ************************************************************************** */
 
 #include "libmng.h"
@@ -180,6 +185,9 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_GETLASTERROR,              "getlasterror"},
     {MNG_FN_READ_RESUME,               "read_resume"},
     {MNG_FN_TRAPEVENT,                 "trapevent"},
+    {MNG_FN_READ_PUSHDATA,             "read_pushdata"},
+    {MNG_FN_READ_PUSHSIG,              "read_pushsig"},
+    {MNG_FN_READ_PUSHCHUNK,            "read_pushchunk"},
 
     {MNG_FN_SETCB_MEMALLOC,            "setcb_memalloc"},
     {MNG_FN_SETCB_MEMFREE,             "setcb_memfree"},
@@ -210,6 +218,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_SETCB_PROCESSUNKNOWN,      "setcb_processunknown"},
     {MNG_FN_SETCB_PROCESSMEND,         "setcb_processmend"},
     {MNG_FN_SETCB_PROCESSTERM,         "setcb_processterm"},
+    {MNG_FN_SETCB_RELEASEDATA,         "setcb_releasedata"},
 
     {MNG_FN_GETCB_MEMALLOC,            "getcb_memalloc"},
     {MNG_FN_GETCB_MEMFREE,             "getcb_memfree"},
@@ -240,6 +249,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_GETCB_PROCESSUNKNOWN,      "getcb_processunknown"},
     {MNG_FN_GETCB_PROCESSMEND,         "getcb_processmend"},
     {MNG_FN_GETCB_PROCESSTERM,         "getcb_processterm"},
+    {MNG_FN_GETCB_RELEASEDATA,         "getcb_releasedata"},
 
     {MNG_FN_SET_USERDATA,              "set_userdata"},
     {MNG_FN_SET_CANVASSTYLE,           "set_canvasstyle"},
@@ -287,6 +297,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_SET_SRGBIMPLICIT,          "set_srgbimplicit"},
     {MNG_FN_SET_CACHEPLAYBACK,         "set_cacheplayback"},
     {MNG_FN_SET_DOPROGRESSIVE,         "set_doprogressive"},
+    {MNG_FN_SET_CRCMODE,               "set_crcmode"},
 
     {MNG_FN_GET_USERDATA,              "get_userdata"},
     {MNG_FN_GET_SIGTYPE,               "get_sigtype"},
@@ -362,6 +373,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_GET_TOTALLAYERS,           "get_totallayers"},
     {MNG_FN_GET_TOTALPLAYTIME,         "get_totalplaytime"},
 #endif
+    {MNG_FN_GET_CRCMODE,               "get_crcmode"},
 
     {MNG_FN_STATUS_ERROR,              "status_error"},
     {MNG_FN_STATUS_READING,            "status_reading"},
@@ -423,10 +435,14 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
 #endif
     {MNG_FN_GETCHUNK_MHDR,             "getchunk_mhdr"},
     {MNG_FN_GETCHUNK_MEND,             "getchunk_mend"},
+#ifndef MNG_SKIPCHUNK_LOOP
     {MNG_FN_GETCHUNK_LOOP,             "getchunk_loop"},
     {MNG_FN_GETCHUNK_ENDL,             "getchunk_endl"},
+#endif
     {MNG_FN_GETCHUNK_DEFI,             "getchunk_defi"},
+#ifndef MNG_SKIPCHUNK_BASI
     {MNG_FN_GETCHUNK_BASI,             "getchunk_basi"},
+#endif
     {MNG_FN_GETCHUNK_CLON,             "getchunk_clon"},
 #ifndef MNG_SKIPCHUNK_PAST
     {MNG_FN_GETCHUNK_PAST,             "getchunk_past"},
@@ -522,7 +538,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
 #ifndef MNG_SKIPCHUNK_tEXt
     {MNG_FN_PUTCHUNK_TEXT,             "putchunk_text"},
 #endif
-#ifndef MNG_SKIPCHUNK_zEXt
+#ifndef MNG_SKIPCHUNK_zTXt
     {MNG_FN_PUTCHUNK_ZTXT,             "putchunk_ztxt"},
 #endif
 #ifndef MNG_SKIPCHUNK_iTXt
@@ -670,6 +686,10 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_READ_DATABUFFER,           "read_databuffer"},
     {MNG_FN_STORE_ERROR,               "store_error"},
     {MNG_FN_DROP_INVALID_OBJECTS,      "drop_invalid_objects"},
+    {MNG_FN_RELEASE_PUSHDATA,          "release_pushdata"},
+    {MNG_FN_READ_DATA,                 "read_data"},
+    {MNG_FN_READ_CHUNK_CRC,            "read_chunk_crc"},
+    {MNG_FN_RELEASE_PUSHCHUNK,         "release_pushchunk"},
 
     {MNG_FN_DISPLAY_RGB8,              "display_rgb8"},
     {MNG_FN_DISPLAY_RGBA8,             "display_rgba8"},
@@ -697,7 +717,7 @@ MNG_LOCAL mng_trace_entry const trace_table [] =
     {MNG_FN_DISPLAY_RGB8_A8,           "display_rgb8_a8"},
     {MNG_FN_DISPLAY_BGRA8PM,           "display_bgra8_pm"},
     {MNG_FN_DISPLAY_BGRX8,             "display_bgrx8"},
-    (MNG_FN_DISPLAY_RGB565,            "display_rgb565"},
+    {MNG_FN_DISPLAY_RGB565,            "display_rgb565"},
     {MNG_FN_DISPLAY_RGBA565,           "display_rgba565"},
     {MNG_FN_DISPLAY_BGR565,            "display_bgr565"},
     {MNG_FN_DISPLAY_BGRA565,           "display_bgra565"},
