@@ -5,7 +5,7 @@
 /* *                                                                        * */
 /* * project   : libmng                                                     * */
 /* * file      : libmng_types.h            copyright (c) 2000-2004 G.Juyn   * */
-/* * version   : 1.0.7                                                      * */
+/* * version   : 1.0.8                                                      * */
 /* *                                                                        * */
 /* * purpose   : type specifications                                        * */
 /* *                                                                        * */
@@ -110,6 +110,10 @@
 /* *                                                                        * */
 /* *             1.0.7 - 03/10/2004 - G.R-P                                 * */
 /* *             - added conditionals around openstream/closestream         * */
+/* *             1.0.8 - 04/11/2004 - G.Juyn                                * */
+/* *             - added data-push mechanisms for specialized decoders      * */
+/* *             1.0.8 - 08/01/2004 - G.Juyn                                * */
+/* *             - added support for 3+byte pixelsize for JPEG's            * */
 /* *                                                                        * */
 /* ************************************************************************** */
 
@@ -178,6 +182,7 @@
 #ifdef FAR
 #undef FAR                             /* possibly defined by zlib or lcms */
 #endif
+#define JPEG_INTERNAL_OPTIONS          /* for RGB_PIXELSIZE */
 #include "jpeglib.h"                   /* all that for JPEG support  :-) */
 #endif /* MNG_INCLUDE_IJG6B */
 
@@ -430,6 +435,10 @@ typedef mng_ptr    (MNG_DECL *mng_memalloc)      (mng_size_t  iLen);
 typedef void       (MNG_DECL *mng_memfree)       (mng_ptr     iPtr,
                                                   mng_size_t  iLen);
 
+typedef void       (MNG_DECL *mng_releasedata)   (mng_ptr     pUserdata,
+                                                  mng_ptr     pData,
+                                                  mng_size_t  iLength);
+
                                        /* I/O management callbacks */
 #ifndef MNG_NO_OPEN_CLOSE_STREAM
 typedef mng_bool   (MNG_DECL *mng_openstream)    (mng_handle  hHandle);
